begin <- "./Figure_S2/"

x <- seq(0, 50, by = 0.001)
diff <- abs(2 * x - 50)/50
prob <- exp(1 * log(10) * diff)

plot(NA,
     xlim = c(0, 2300),
     ylim = c(0, 25),
     xlab = "Number of Generations",
     ylab = "Number of junctions",
     main = "")

hexes <- c("#0299F5", "#CEB400", "#6B944D")
colVals <- list(col2rgb(col = hexes[1])/255,
                col2rgb(col = hexes[2])/255,
                col2rgb(col = hexes[3])/255)

l <- 50
colcnt <- 1
for (p in c(5, 7, 9)) {
    d <- read.table(paste(begin, "/", p, "/record.txt", sep = ""),
                    header = F)
    d2 <- d

    xmin <- c()
    xmean <- c()
    xmax <- c()
    tVals <- c()
    for (j in 7:2006) {
        if ((j - 7)%%25 == 0) {
            v <- d2[, j]
            xmean <- c(xmean, mean(v))

            stdErr <- sd(v)/sqrt(length(v))
            Q <- c(mean(v) - stdErr, mean(v) + stdErr)
            xmin <- c(xmin, Q[[1]])
            xmax <- c(xmax, Q[[2]])
            tVals <- c(tVals, c(j - 7))
        }
    }

    points(xmean ~ tVals,
           col = rgb(colVals[[colcnt]][1],
                     colVals[[colcnt]][2],
                     colVals[[colcnt]][3]))

    arrows(tVals, xmin, tVals, xmax, length = 0.05, angle = 90, code = 3,
           col = rgb(colVals[[colcnt]][1],
                     colVals[[colcnt]][2],
                     colVals[[colcnt]][3]),
           lwd = 2)

    H_0 <- 2 * p/10 * (1 - p/10)
    nt <- junctions::number_of_junctions(N = 100000, R = 50, H_0, t = 1:2000)

    lines(nt,
          col = rgb(colVals[[colcnt]][1],
                    colVals[[colcnt]][2],
                    colVals[[colcnt]][3]),
          lwd = 1)

    text(x = 2170,
         y = xmean[length(xmean)],
         paste("p =", p/10),
         col = rgb(colVals[[colcnt]][1],
                   colVals[[colcnt]][2],
                   colVals[[colcnt]][3]),
         cex = 1)

     colcnt <- colcnt + 1
}

labz <- seq(0, 10, by = 2)

library("TeachingDemos")
subplot(
  c(
    plot(prob ~ x,
         type = "l",
         xaxt = "n",
         yaxt = "n",
         xlab = "",
         ylab = "",
         cex.axis = 0.7,
         ylim = c(0, 11)),
    abline(v = 25, lty = 2),
    axis(1, las = 1,
            cex.axis = 0.7,
            at = seq(0, 50, by = 10),
            label = rep("", 6),
            tck = -0.05),
    axis(1, las = 1,
            line = -0.7,
            lwd = 0,
            cex.axis = 0.7,
            at = seq(0, 50, by = 10),
            label = seq(0, 50, by = 10)),
    axis(2, las = 1,
            cex.axis = 0.7,
            at = labz,
            label = rep("", length(labz)), tcl = -0.2),
    axis(2, las = 1,
            line = -0.7,
            lwd = 0,
            cex.axis = 0.7,
            at = labz,
            label = labz, tcl = -0.2),
    mtext(side = 2,
          text = "Relative Recombination\n Probability",
          line = 1,
          cex = 0.7),
    mtext(side = 1,
          text = "Chromosome position",
          line = 1,
          cex = 0.7)),
    x = c(700, 2200),
    y = c(1.75, 7.5))